pub struct KeyRuntimeDetails {
pub normal_separator: &'static str,
pub reverse_separator: &'static str,
pub show_probe_names: bool,
pub show_paths_without_thread_number: bool,
pub show_paths_with_thread_number: bool,
pub show_paths_reversed_too: bool,
pub key_column_width: Option<f64>,
pub prefix: Option<&'static str>,
pub skip_process: bool,
}Expand description
How keys (in AllFieldsTable) are presented, and, unlike what the
name suggests, also what rows are generated, since the grouping of
the measurements depends on the set of generated key
strings. (This only contains the runtime data, but unlike what the
name suggests, actually there is no static data for the key column
in the output? (PS. But there is the definition of the trait
KeyDetails below, can’t conflict with that.))
Fields
normal_separator: &'static strThe separators to use
reverse_separator: &'static strshow_probe_names: boolWhether to use the probe names as keys (versus paths)
show_paths_without_thread_number: boolshow_paths_with_thread_number: boolshow_paths_reversed_too: boolkey_column_width: Option<f64>prefix: Option<&'static str>Override the standard prefixes–the same is used for all modes above!
skip_process: boolDo not show process measurement (used for flamegraph)